@@ -19,7 +19,6 @@ package org.apache.eventmesh.connector.rocketmq.producer;
 
 import org.apache.eventmesh.api.RequestReplyCallback;
 import org.apache.eventmesh.api.SendCallback;
-import org.apache.eventmesh.api.SendResult;
 import org.apache.eventmesh.api.producer.Producer;
 import org.apache.eventmesh.connector.rocketmq.common.EventMeshConstants;
 import org.apache.eventmesh.connector.rocketmq.config.ClientConfiguration;
@@ -83,11 +82,6 @@ public class RocketMQProducerImpl implements Producer {
         producer.sendAsync(message, sendCallback);
     }
 
-    @Override
-    public SendResult publish(CloudEvent message) {
-        return producer.send(message);
-    }
-
     @Override
     public void request(CloudEvent message, RequestReplyCallback rrCallback, long timeout)
             throws InterruptedException, RemotingException, MQClientException, MQBrokerException {
@@ -116,11 +110,4 @@ public class RocketMQProducerImpl implements Producer {
     public void sendOneway(CloudEvent message) {
         producer.sendOneway(message);
     }
-
-    @Override
-    public void sendAsync(CloudEvent message, SendCallback sendCallback) {
-        producer.sendAsync(message, sendCallback);
-    }
-
-
 }
