@@ -47,6 +47,8 @@ public class EventMeshHTTPConfiguration extends CommonConfiguration {
 
     public int eventMeshServerSendMsgThreadNum = 8;
 
+    public int eventMeshServerRemoteMsgThreadNum = 8;
+
     public int eventMeshServerPushMsgThreadNum = 8;
 
     public int eventMeshServerReplyMsgThreadNum = 8;
@@ -69,6 +71,8 @@ public class EventMeshHTTPConfiguration extends CommonConfiguration {
 
     public int eventMeshServerSendMsgBlockQSize = 1000;
 
+    public int eventMeshServerRemoteMsgBlockQSize = 1000;
+
     public int eventMeshServerPushMsgBlockQSize = 1000;
 
     public int eventMeshServerClientManageBlockQSize = 1000;
@@ -142,6 +146,14 @@ public class EventMeshHTTPConfiguration extends CommonConfiguration {
                         Integer.parseInt(StringUtils.deleteWhitespace(eventMeshServerSendMsgThreadNumStr));
             }
 
+            String eventMeshServerRemoteMsgThreadNumStr =
+                configurationWrapper.getProp(ConfKeys.KEYS_EVENTMESH_REMOTEMSG_THREAD_NUM);
+            if (StringUtils.isNotEmpty(eventMeshServerRemoteMsgThreadNumStr)
+                && StringUtils.isNumeric(eventMeshServerRemoteMsgThreadNumStr)) {
+                eventMeshServerRemoteMsgThreadNum =
+                    Integer.parseInt(StringUtils.deleteWhitespace(eventMeshServerRemoteMsgThreadNumStr));
+            }
+
             String eventMeshServerReplyMsgThreadNumStr =
                     configurationWrapper.getProp(ConfKeys.KEYS_EVENTMESH_REPLYMSG_THREAD_NUM);
             if (StringUtils.isNotEmpty(eventMeshServerReplyMsgThreadNumStr)
@@ -323,6 +335,8 @@ public class EventMeshHTTPConfiguration extends CommonConfiguration {
 
         public static String KEYS_EVENTMESH_SENDMSG_THREAD_NUM = "eventMesh.server.sendmsg.threads.num";
 
+        public static String KEYS_EVENTMESH_REMOTEMSG_THREAD_NUM = "eventMesh.server.remotemsg.threads.num";
+
         public static String KEYS_EVENTMESH_REPLYMSG_THREAD_NUM = "eventMesh.server.replymsg.threads.num";
 
         public static String KEYS_EVENTMESH_PUSHMSG_THREAD_NUM = "eventMesh.server.pushmsg.threads.num";
