@@ -17,22 +17,24 @@
 
 package org.apache.eventmesh.runtime.core.protocol.http.producer;
 
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-
-import io.cloudevents.CloudEvent;
-
-import org.apache.commons.lang3.time.DateFormatUtils;
 import org.apache.eventmesh.api.SendCallback;
 import org.apache.eventmesh.api.SendResult;
 import org.apache.eventmesh.api.exception.OnExceptionContext;
 import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.runtime.boot.EventMeshHTTPServer;
 import org.apache.eventmesh.runtime.core.protocol.http.retry.RetryContext;
+
+import org.apache.commons.lang3.time.DateFormatUtils;
+
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import io.cloudevents.CloudEvent;
+
 public class SendMessageContext extends RetryContext {
 
     public static Logger logger = LoggerFactory.getLogger("retry");
@@ -141,7 +143,7 @@ public class SendMessageContext extends RetryContext {
             @Override
             public void onException(OnExceptionContext context) {
                 logger.warn("", context.getException());
-                eventMeshHTTPServer.metrics.summaryMetrics.recordSendBatchMsgFailed(1);
+                eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendBatchMsgFailed(1);
             }
 
         });
