@@ -17,13 +17,18 @@
 
 package org.apache.eventmesh.runtime.core.protocol.http.push;
 
+import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.common.ThreadPoolFactory;
 import org.apache.eventmesh.runtime.core.protocol.http.consumer.EventMeshConsumer;
 import org.apache.eventmesh.runtime.core.protocol.http.consumer.HandleMsgContext;
+import org.apache.eventmesh.runtime.trace.TraceUtils;
+import org.apache.eventmesh.runtime.util.EventMeshUtil;
+import org.apache.eventmesh.trace.api.common.EventMeshTraceConstants;
 
 import org.apache.commons.collections4.MapUtils;
 
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.RejectedExecutionException;
 import java.util.concurrent.ScheduledExecutorService;
@@ -33,6 +38,8 @@ import java.util.concurrent.TimeUnit;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import io.opentelemetry.api.trace.Span;
+
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
 
@@ -69,22 +76,33 @@ public class HTTPMessageHandler implements MessageHandler {
     @Override
     public boolean handle(final HandleMsgContext handleMsgContext) {
         Set waitingRequests4Group = MapUtils.getObject(waitingRequests,
-                handleMsgContext.getConsumerGroup(), Sets.newConcurrentHashSet());
+            handleMsgContext.getConsumerGroup(), Sets.newConcurrentHashSet());
         if (waitingRequests4Group.size() > CONSUMER_GROUP_WAITING_REQUEST_THRESHOLD) {
             logger.warn("waitingRequests is too many, so reject, this message will be send back to MQ, consumerGroup:{}, threshold:{}",
-                    handleMsgContext.getConsumerGroup(), CONSUMER_GROUP_WAITING_REQUEST_THRESHOLD);
+                handleMsgContext.getConsumerGroup(), CONSUMER_GROUP_WAITING_REQUEST_THRESHOLD);
             return false;
         }
 
         try {
             pushExecutor.submit(() -> {
-                AsyncHTTPPushRequest asyncPushRequest = new AsyncHTTPPushRequest(handleMsgContext, waitingRequests);
-                asyncPushRequest.tryHTTPRequest();
+                String protocolVersion = Objects.requireNonNull(handleMsgContext.getEvent().getExtension(
+                    Constants.PROTOCOL_VERSION)).toString();
+
+                Span span = TraceUtils.prepareClientSpan(EventMeshUtil.getCloudEventExtensionMap(protocolVersion, handleMsgContext.getEvent()),
+                    EventMeshTraceConstants.TRACE_DOWNSTREAM_EVENTMESH_CLIENT_SPAN, false);
+
+                try {
+                    AsyncHTTPPushRequest asyncPushRequest = new AsyncHTTPPushRequest(handleMsgContext, waitingRequests);
+                    asyncPushRequest.tryHTTPRequest();
+                } finally {
+                    TraceUtils.finishSpan(span, handleMsgContext.getEvent());
+                }
+
             });
             return true;
         } catch (RejectedExecutionException e) {
             logger.warn("pushMsgThreadPoolQueue is full, so reject, current task size {}",
-                    handleMsgContext.getEventMeshHTTPServer().getPushMsgExecutor().getQueue().size(), e);
+                handleMsgContext.getEventMeshHTTPServer().getPushMsgExecutor().getQueue().size(), e);
             return false;
         }
     }
