@@ -20,8 +20,6 @@ package org.apache.eventmesh.runtime.core.protocol.tcp.client.task;
 import static org.apache.eventmesh.common.protocol.tcp.Command.HEARTBEAT_REQUEST;
 import static org.apache.eventmesh.common.protocol.tcp.Command.HEARTBEAT_RESPONSE;
 
-import io.netty.channel.ChannelHandlerContext;
-
 import org.apache.eventmesh.common.protocol.tcp.Header;
 import org.apache.eventmesh.common.protocol.tcp.OPStatus;
 import org.apache.eventmesh.common.protocol.tcp.Package;
@@ -30,6 +28,8 @@ import org.apache.eventmesh.runtime.boot.EventMeshTCPServer;
 import org.apache.eventmesh.runtime.util.RemotingHelper;
 import org.apache.eventmesh.runtime.util.Utils;
 
+import io.netty.channel.ChannelHandlerContext;
+
 public class HeartBeatTask extends AbstractTask {
 
     public HeartBeatTask(Package pkg, ChannelHandlerContext ctx, long startTime, EventMeshTCPServer eventMeshTCPServer) {
@@ -42,7 +42,7 @@ public class HeartBeatTask extends AbstractTask {
         Package res = new Package();
         try {
             //do acl check in heartbeat
-            if(eventMeshTCPServer.getEventMeshTCPConfiguration().eventMeshServerSecurityEnable){
+            if (eventMeshTCPServer.getEventMeshTCPConfiguration().eventMeshServerSecurityEnable) {
                 String remoteAddr = RemotingHelper.parseChannelRemoteAddr(ctx.channel());
                 Acl.doAclCheckInTcpHeartbeat(remoteAddr, session.getClient(), HEARTBEAT_REQUEST.value());
             }
@@ -53,8 +53,8 @@ public class HeartBeatTask extends AbstractTask {
             res.setHeader(new Header(HEARTBEAT_RESPONSE, OPStatus.SUCCESS.getCode(), OPStatus.SUCCESS.getDesc(), pkg.getHeader().getSeq()));
         } catch (Exception e) {
             logger.error("HeartBeatTask failed|user={}|errMsg={}", session.getClient(), e);
-            res.setHeader(new Header(HEARTBEAT_RESPONSE, OPStatus.FAIL.getCode(), "exception while " +
-                    "heartbeating", pkg.getHeader().getSeq()));
+            res.setHeader(new Header(HEARTBEAT_RESPONSE, OPStatus.FAIL.getCode(), "exception while "
+                    + "heartbeating", pkg.getHeader().getSeq()));
         } finally {
             Utils.writeAndFlush(res, startTime, taskExecuteTime, session.getContext(), session);
         }
