@@ -54,10 +54,18 @@ public class Registry {
         return registryService.findEventMeshInfoByCluster(clusterName);
     }
 
+    public List<EventMeshDataInfo> findAllEventMeshInfo() throws Exception {
+        return registryService.findAllEventMeshInfo();
+    }
+
     public Map<String, Map<String, Integer>> findEventMeshClientDistributionData(String clusterName, String group, String purpose) throws Exception {
         return registryService.findEventMeshClientDistributionData(clusterName, group, purpose);
     }
 
+    public void registerMetadata(Map<String, String> metadata) {
+        registryService.registerMetadata(metadata);
+    }
+
     public boolean register(EventMeshRegisterInfo eventMeshRegisterInfo) throws Exception {
         return registryService.register(eventMeshRegisterInfo);
     }
