@@ -26,6 +26,8 @@ public enum EventMeshExtensionType {
     REGISTRY("registry"),
     SECURITY("security"),
     PROTOCOL("protocol"),
+    METRICS("metrics"),
+    TRACE("trace"),
     ;
 
     private final String extensionTypeName;
